package kaysaar.aotd_question_of_loyalty.data.scripts.trackers;

import com.fs.starfarer.api.campaign.comm.IntelInfoPlugin;
import com.fs.starfarer.api.Global;
import java.util.Iterator;
import com.fs.starfarer.api.impl.campaign.intel.events.EventFactor;
import kaysaar.aotd_question_of_loyalty.data.intel.eventfactors.onetime.BountyCompletionFactor;
import kaysaar.aotd_question_of_loyalty.data.intel.AoTDCommIntelPlugin;
import org.lazywizard.lazylib.MathUtils;
import kaysaar.aotd_question_of_loyalty.data.misc.QoLMisc;
import com.fs.starfarer.api.impl.campaign.intel.PersonBountyIntel;
import com.fs.starfarer.api.impl.campaign.missions.cb.BaseCustomBounty;
import java.util.ArrayList;
import com.fs.starfarer.api.EveryFrameScript;

public class BountyTracker implements EveryFrameScript
{
    protected ArrayList<BaseCustomBounty> baseCustomBounties;
    protected ArrayList<PersonBountyIntel> basePersonBounties;
    
    public BountyTracker() {
        this.baseCustomBounties = new ArrayList<BaseCustomBounty>();
        this.basePersonBounties = new ArrayList<PersonBountyIntel>();
    }
    
    public boolean isDone() {
        return false;
    }
    
    public boolean runWhilePaused() {
        return false;
    }
    
    public void advance(final float amount) {
        this.handleBarBounties();
        this.handlePersonalBounties();
    }
    
    private void handleBarBounties() {
        for (final BaseCustomBounty bounty : this.getBaseBounties()) {
            if (bounty.getResult() != null && QoLMisc.isCommissionedBy(bounty.getFactionForUIColors().getId()) && !this.isBaseBountyPresent(bounty)) {
                this.baseCustomBounties.add(bounty);
                int val = 0;
                if (!bounty.getResult().success) {
                    val = -20;
                }
                else {
                    val = MathUtils.getRandomNumberInRange(50, 120);
                }
                AoTDCommIntelPlugin.get().addFactor((EventFactor)new BountyCompletionFactor(val));
            }
        }
        final Iterator<BaseCustomBounty> iterator = this.baseCustomBounties.iterator();
        while (iterator.hasNext()) {
            final BaseCustomBounty baseCustomBounty = iterator.next();
            if (baseCustomBounty.isEnded()) {
                iterator.remove();
            }
        }
    }
    
    public ArrayList<BaseCustomBounty> getBaseBounties() {
        final ArrayList<BaseCustomBounty> bounties = new ArrayList<BaseCustomBounty>();
        for (final IntelInfoPlugin intelInfoPlugin : Global.getSector().getIntelManager().getIntel((Class)BaseCustomBounty.class)) {
            if (intelInfoPlugin instanceof final BaseCustomBounty baseCustomBounty) {
                bounties.add(baseCustomBounty);
            }
        }
        return bounties;
    }
    
    public boolean isBaseBountyPresent(final BaseCustomBounty bounty) {
        for (final BaseCustomBounty baseCustomBounty : this.baseCustomBounties) {
            if (bounty.getMissionId().equals(baseCustomBounty.getMissionId())) {
                return true;
            }
        }
        return false;
    }
    
    private void handlePersonalBounties() {
        for (final PersonBountyIntel bounty : this.getPersonBounties()) {
            if (bounty.getResult() != null && QoLMisc.isCommissionedBy(bounty.getFactionForUIColors().getId()) && !this.isPersonalBountyPresent(bounty)) {
                this.basePersonBounties.add(bounty);
                if (!bounty.getResult().type.equals((Object)PersonBountyIntel.BountyResultType.END_PLAYER_BOUNTY)) {
                    continue;
                }
                final int points = (int)(bounty.getBountyCredits() / 10000.0f);
                AoTDCommIntelPlugin.get().addFactor((EventFactor)new BountyCompletionFactor(points));
            }
        }
        final Iterator<BaseCustomBounty> iterator = this.baseCustomBounties.iterator();
        while (iterator.hasNext()) {
            final BaseCustomBounty baseCustomBounty = iterator.next();
            if (baseCustomBounty.isEnded()) {
                iterator.remove();
            }
        }
    }
    
    public ArrayList<PersonBountyIntel> getPersonBounties() {
        final ArrayList<PersonBountyIntel> bounties = new ArrayList<PersonBountyIntel>();
        for (final IntelInfoPlugin intelInfoPlugin : Global.getSector().getIntelManager().getIntel((Class)PersonBountyIntel.class)) {
            if (intelInfoPlugin instanceof final PersonBountyIntel personBountyIntel) {
                bounties.add(personBountyIntel);
            }
        }
        return bounties;
    }
    
    public boolean isPersonalBountyPresent(final PersonBountyIntel bounty) {
        for (final PersonBountyIntel baseCustomBounty : this.basePersonBounties) {
            if (bounty.equals(baseCustomBounty)) {
                return true;
            }
        }
        return false;
    }
}
